@@ -1,6 +1,9 @@
 package # hide from PAUSE
     DBICTest::Schema::SerializeJSON;
 
+use strict;
+use warnings;
+
 use base qw/DBIx::Class/;
 
 __PACKAGE__->load_components (qw/InflateColumn::Serializer Core/);
@@ -20,6 +23,12 @@ __PACKAGE__->add_columns(
     data_type => 'varchar',
     serializer_class => 'JSON',
     is_nullable => 1,
+  },
+  'serial3' => {
+    data_type => 'varchar',
+    serializer_class => 'JSON',
+    serializer_options => { allow_nonref => 1 },
+    is_nullable => 1,
   }
 );
 
